==> react_image_annotate_ns_workflow-1.1.2.tgz: package/LazyBrush/BrushSlider.js <==
import BrushIcon from "@mui/icons-material/Brush";
import ClearAllIcon from "@mui/icons-material/ClearAll";
import { createTheme, Fab, Tooltip } from "@mui/material";
import Slider from "@mui/material/Slider";
import * as React from "react";
export default function VerticalSlider(_ref) {
  var setTool = _ref.setTool,
      brushRadius = _ref.brushRadius,
      setbrushRadius = _ref.setbrushRadius,
      selectTool = _ref.selectTool;

  function preventHorizontalKeyboardNavigation(event) {
    if (event.key === "ArrowLeft" || event.key === "ArrowRight") {
      event.preventDefault();
    }
  }

  var muiTheme = createTheme({
    slider: {
      trackColor: "yellow",
      selectionColor: "red"
    }
  });
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Slider, {
    sx: {
      '& input[type="range"]': {
        WebkitAppearance: "slider-vertical"
      }
    },
    marks: true,
    orientation: "vertical",
    defaultValue: 30,
    "aria-label": "Temperature",
    valueLabelDisplay: "auto",
    onKeyDown: preventHorizontalKeyboardNavigation,
    onChange: function onChange(e) {
      setbrushRadius(e.target.value);
    },
    value: brushRadius,
    max: 20,
    min: 1,
    size: "small" // classes={{
    //   thumb: classes.thumb,
    //   rail: classes.rail,
    //   track: classes.track,
    //   valueLabel: classes.valueLabel,
    //   mark: classes.mark,
    // }}

  }), selectTool === "create-a-brush" && /*#__PURE__*/React.createElement(Tooltip, {
    title: "Brush",
    placement: "right"
  }, /*#__PURE__*/React.createElement(Fab, {
    style: {
      width: "20px",
      minHeight: "20px",
      height: "20px",
      marginTop: "1px",
      background: "rgb(0, 95, 134)"
    },
    size: "small",
    color: "primary",
    "aria-label": "add",
    marks: true,
    onClick: function onClick() {
      return setTool("pen");
    } // components={{ Thumb: AirbnbThumbComponent }}

  }, /*#__PURE__*/React.createElement(BrushIcon, {
    style: {
      width: "0.7rem",
      height: "0.7rem"
    }
  }))), selectTool === "eraser" && /*#__PURE__*/React.createElement(Tooltip, {
    title: "Eraser",
    placement: "right"
  }, /*#__PURE__*/React.createElement(Fab, {
    style: {
      width: "20px",
      minHeight: "20px",
      height: "20px",
      marginTop: "1px",
      background: "rgb(0, 95, 134)"
    },
    size: "small",
    color: "primary",
    onClick: function onClick() {
      return setTool("eraser");
    }
  }, /*#__PURE__*/React.createElement(ClearAllIcon, {
    style: {
      width: "0.7rem",
      height: "0.7rem"
    }
  }))));
}

==> react_image_annotate_ns_workflow-4.0.8.tgz: package/LazyBrush/BrushSlider.js <==
import BrushIcon from "@mui/icons-material/Brush";
import ClearAllIcon from "@mui/icons-material/ClearAll";
import { createTheme, Fab, Tooltip } from "@mui/material";
import Slider from "@mui/material/Slider";
import * as React from "react";
export default function VerticalSlider(_ref) {
  var setTool = _ref.setTool,
    brushRadius = _ref.brushRadius,
    setbrushRadius = _ref.setbrushRadius,
    selectTool = _ref.selectTool;
  function preventHorizontalKeyboardNavigation(event) {
    if (event.key === "ArrowLeft" || event.key === "ArrowRight") {
      event.preventDefault();
    }
  }
  var muiTheme = createTheme({
    slider: {
      trackColor: "yellow",
      selectionColor: "red"
    }
  });
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Slider, {
    sx: {
      '& input[type="range"]': {
        WebkitAppearance: "slider-vertical"
      }
    },
    marks: true,
    orientation: "vertical",
    defaultValue: 30,
    "aria-label": "Temperature",
    valueLabelDisplay: "auto",
    onKeyDown: preventHorizontalKeyboardNavigation,
    onChange: function onChange(e) {
      setbrushRadius(e.target.value);
    },
    value: brushRadius,
    max: 20,
    min: 1,
    size: "small"
    // classes={{
    //   thumb: classes.thumb,
    //   rail: classes.rail,
    //   track: classes.track,
    //   valueLabel: classes.valueLabel,
    //   mark: classes.mark,
    // }}
  }), selectTool === "create-a-brush" && /*#__PURE__*/React.createElement(Tooltip, {
    title: "Brush",
    placement: "right"
  }, /*#__PURE__*/React.createElement(Fab, {
    style: {
      width: "20px",
      minHeight: "20px",
      height: "20px",
      marginTop: "1px",
      background: "rgb(0, 95, 134)"
    },
    size: "small",
    color: "primary",
    "aria-label": "add",
    marks: true,
    onClick: function onClick() {
      return setTool("pen");
    }
    // components={{ Thumb: AirbnbThumbComponent }}
  }, /*#__PURE__*/React.createElement(BrushIcon, {
    style: {
      width: "0.7rem",
      height: "0.7rem"
    }
  }))), selectTool === "eraser" && /*#__PURE__*/React.createElement(Tooltip, {
    title: "Eraser",
    placement: "right"
  }, /*#__PURE__*/React.createElement(Fab, {
    style: {
      width: "20px",
      minHeight: "20px",
      height: "20px",
      marginTop: "1px",
      background: "rgb(0, 95, 134)"
    },
    size: "small",
    color: "primary",
    onClick: function onClick() {
      return setTool("eraser");
    }
  }, /*#__PURE__*/React.createElement(ClearAllIcon, {
    style: {
      width: "0.7rem",
      height: "0.7rem"
    }
  }))));
}
